if (typeof Element !== "undefined") {
  if (!Element.prototype.matches) {
    Element.prototype.matches = Element.prototype.msMatchesSelector || Element.prototype.webkitMatchesSelector;
  }
  if (!Element.prototype.closest) {
    Element.prototype.closest = function(s) {
      let el = this;
      do {
        if (el.matches(s)) {
          return el;
        }
        el = el.parentElement || el.parentNode;
      } while (el !== null && el.nodeType === 1);
      return null;
    };
  }
}
const vueCatchHrefs = {
  install: function install(_, { router, pathFormatter }) {
    if (pathFormatter === void 0)
      pathFormatter = null;
    if (!router) {
      throw new Error(
        "Cannot find the router, please use vue-router to catch redirections."
      );
    }
    window.addEventListener("click", function(event) {
      const metaKey = event.metaKey;
      const altKey = event.altKey;
      const ctrlKey = event.ctrlKey;
      const shiftKey = event.shiftKey;
      const defaultPrevented = event.defaultPrevented;
      const button = event.button;
      if (defaultPrevented) {
        return;
      }
      if (metaKey || altKey || ctrlKey || shiftKey) {
        return;
      }
      if (button !== void 0 && button !== 0) {
        return;
      }
      const target = event.target || event.srcElement;
      const from = target.closest("a");
      if (!from) {
        return;
      }
      const appPath = window.location.protocol + "//" + window.location.host;
      if (from.href.includes(appPath)) {
        let url;
        try {
          url = new URL(from.href);
        } catch (e) {
          return;
        }
        let path = url.pathname;
        if (pathFormatter) {
          path = pathFormatter(path, router.currentRoute);
        }
        if (path) {
          event.preventDefault();
          if (router.currentRoute.path !== path) {
            router.push({
              path
            });
          }
        }
      }
    });
  }
};
export { vueCatchHrefs };
